#!/bin/bash
# IBM Confidential
# OCO Source Materials
# 5724-V51
#
# (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
# 
# # Copyright (c) 2000, 2004 IBM Corp. - All Rights Reserved.
# # IBM makes no representations or warranties about the suitability of
# # this program, either express or implied, including but not limited to
# # the implied warranties of merchantability, fitness for a particular
# # purpose, or non-infringement. 
# 
#


${MKDIR} ${SVC_LOG_DIR}/${SVC_NAME}

PID=${SVC_LOG_DIR}/${SVC_NAME}/svc.pid
LOG=${SVC_LOG_DIR}/${SVC_NAME}/svc.out
JAVA_RT_HOTSPOT="${JDK_HOME}/bin/java ${COMMON_JAVA_OPTIONS}"

# read the right com.ibm.ccd.common.properties
if [ -e "${CCD_ETC_DIR}/${SVC_NAME}/common.properties" ]; then
    . $TOP/bin/read_config_file.sh ${CCD_ETC_DIR}/${SVC_NAME}/common.properties
else
    . $TOP/bin/read_config_file.sh ${CCD_ETC_DIR}/default/common.properties
fi


# start cmd in background and outputs stdout and stderr to log file
# also saves pid of cmd to pid file
startWithLogs() {

    #ensure ;'s are escaped before passing to bash, avoid already escaped ;'s
    CMD=`${ECHO} $@ | ${SED} -e 's#\([^\\]\)\;#\1\\\;#g'`
    
    TXT1="Starting trigo service: '${SVC_NAME}' at `date`"
    TXT2="Using command: $CMD"
    TXT3="---------------------------------------------"	
    
    if [ ! -z "${_CCD_NOLOG}" ]; then
        ${ECHO} ${TXT1}
        ${ECHO}
        ${ECHO} ${TXT2}
        ${ECHO} ${TXT3}

	bash -c "$CMD" &

        ${ECHO} $! > $PID
    else
        ${ECHO} ${TXT1} > $LOG
        ${ECHO} >> $LOG
        ${ECHO} ${TXT2} >> $LOG
        ${ECHO} ${TXT3} >> $LOG

	bash -c "$CMD" >> $LOG 2>&1 &

        ${ECHO} $! > $PID
    fi
}

# compares version of db schema to current code version.  
# Returns 0 if they are the same, 1 if not
CheckDbSchemaVersion() {

	retval=0

	${JAVA_RT} com.ibm.ccd.synchronize.DBSchemaVersion --verify > $TOP/schemaValid.txt
  
	NOSYNCH=`${GREP} "False" $TOP/schemaValid.txt|${AWK} '{print $1}'`

	if [ -n "$NOSYNCH" ]; then
		${ECHO} "***** ERROR *********"
		${ECHO} "Schema synchronization error. The database and codeline are not in step."
		${ECHO} "To avoid possible data corruption the application will not be started"		
		${ECHO} 
		${ECHO} "You must update your schema before proceeding"						
		${ECHO} 
		retval=1
	fi

	${RM} $TOP/schemaValid.txt

	return $retval
}


# FindEtcDirForAppSvr <appsvr type>
#   find if there is a ${CCD_ETC_DIR}/<svc_name>/<appsvr type> directory
#   if it does not exist, use the default directory
InitEtcDirForAppSvr() {
    if [ -d "${CCD_ETC_DIR}/${SVC_NAME}/$1" ]; then
        SVC_ETC_DIR=${CCD_ETC_DIR}/${SVC_NAME}
    else
        SVC_ETC_DIR=${CCD_ETC_DIR}/default
    fi
    
    APPSVR_OPTS="${CLIENT_SERVER_JAVA_OPTION} $APPSVR_MEMORY_FLAG $BASIC_JAVA_OPTIONS -Dtrigo.memflags='$APPSVR_MEMORY_FLAG' -Dsvc_name=${SVC_NAME} -Dsvc_etc_dir=${SVC_ETC_DIR} -Dtrigo_url=${CCD_URL}"
}
