#!/bin/bash
# IBM Confidential
# OCO Source Materials
# 5724-V51
#
# (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.


#  Usage: loadlkps.sh COMPANY_CODE USERNAME PATH
#
#  Use this script to 'load' lookup tables into the product
#  This script will:
#     1) create an lkp for the data to load
#     2) create a feed to aggregate the data
#     3) load the data into the docstore and associate it with the created feed
#     4) aggregate the loaded data
#
#  ex: loadlkps.sh acme2 Admin '/lkp/acme'
#  This will load create a lkp for each lkp data file found in the 'src/db/lkp/acme' directory


export company_code=$1
export username=$2
export path=$3


function createLkp
{

filespec=$1
specmap=$2

echo "Creating Lookup Table [ $lkp ] ..."
$JAVA_RT com.ibm.ccd.common.setup.CatalogCreator -company_code=$company_code \
                                           -catalog_name=$lkp \
                                           -ctr_name="content tree 2" \
                                           -catalog_type="LOOKUP_TABLE" \
                                           -spec_name="Lookup Table Import Spec" \

echo "Creating Feed [ $lkp ] for the Lookup table..."
$JAVA_RT com.ibm.ccd.common.setup.FeedCreator -company_code=$company_code \
                                        -username=$username \
                                        -feed_name=$lkp \
                                        -feed_type=ITM \
                                        -data_src_name=browser \
                                        -file_spec_name=$filespec \
                                        -catalog_name=$lkp \
                                        -spec_map_name=$specmap \
                                        -script_name=""



. ${TOP}/bin/read_config_file.sh
$MKDIR ${_TRIGO_CONF_TMP_DIR}
xmltmpfile=${_TRIGO_CONF_TMP_DIR}loadlkps.sh.tmp
tmp_load_log_file=${_TRIGO_CONF_TMP_DIR}loadlkps.sh.load_log_file_${filespec}_${specmap}.txt

docstorepath="/public_html/aggregated_files/${lkp}.TXT"

cat > $xmltmpfile << EOF
<?xml version="1.0" encoding="UTF-8"?>
<DocListXML>
    <Doc type="feed">
        <LocalPath>$path/$filename</LocalPath>
        <StorePath>$docstorepath</StorePath>
        <Attribs>
            <Attrib name="feed_name" value="$lkp"/>
        </Attribs>
     </Doc>
</DocListXML>
EOF

echo "Loading LookupTable  data ..."
$JAVA_RT com.ibm.ccd.docstore.util.DocLoader $company_code $username $xmltmpfile


echo "Aggregating LookupTable  data ..."
$JAVA_RT  com.ibm.ccd.connectivity.common.CtgToDb -company_code=$company_code -user=$username -doc_store_path=$docstorepath -feed_name=$lkp >& $tmp_load_log_file
if [ $? -ne 0 ]; then
    echo "    Error occurred while aggregating data.";
    echo "    Look in $tmp_load_log_file for log";
fi
}



cd $TOP/src/db$path
lkps=$(\ls *)

for filename in $lkps; do

if [ ${filename%.txt} != $filename ]; then
    # assume pipe delimited
    lkp=${filename%.txt}
    createLkp "LkpPipe" "LkpPipeMap"
elif [ ${filename%.csv} != $filename ]; then
   lkp=${filename%.csv}
   createLkp "LkpCsv" "LkpCsvMap"
elif  [ ${filename%.tab} != $filename ]; then
   lkp=${filename%.tab}
   createLkp "LkpTab" "LkpTabMap"
fi

done
rm $xmltmpfile;
cd -
