#!/bin/ksh

# Copyright (c) 2000, 2004 IBM Corp. - All Rights Reserved.
# IBM makes no representations or warranties about the suitability of
# this program, either express or implied, including but not limited to
# the implied warranties of merchantability, fitness for a particular
# purpose, or non-infringement. 

echo
echo ====================================================
echo creating temporary files and directories...
echo ====================================================

mkdir -p $DB_ROOT_DIR/schema/create/_lookup_table_migration
mkdir -p $DB_ROOT_DIR/schema/create/_lookup_table_migration/specs
mkdir -p $DB_ROOT_DIR/schema/create/_lookup_table_migration/csv

TEMP_LOOKUP_DIR="${DB_ROOT_DIR}/schema/create/_lookup_table_migration"

TMP_LKPS_OUTPUT_FILE="${TEMP_LOOKUP_DIR}/_lkp_tables.out"
LKPS_OUTPUT_FILE="${TEMP_LOOKUP_DIR}/lkp_tables.out"

TMP_COLS_OUTPUT_FILE="${TEMP_LOOKUP_DIR}/_columns.out"
COLS_OUTPUT_FILE="${TEMP_LOOKUP_DIR}/columns.out"

TMP_CSV_OUTPUT_FILE="${TEMP_LOOKUP_DIR}/__lookup_table.csv"
CSV_OUTPUT_FILE="${TEMP_LOOKUP_DIR}/_lookup_table.csv"

FINAL_CSV_OUTPUT_FILE="${TEMP_LOOKUP_DIR}/lookup_table.csv"

#rm ${TEMP_LOOKUP_DIR}/specs/*.*

. ${TOP}/src/db/schema/util/set_db.sh

cd $TEMP_LOOKUP_DIR

echo database username:     ${DB_USER_NAME}
echo database user passwd:  ${DB_USER_PWD}
echo database service name: ${CONNECTION}

echo ====================================================
echo creating specs for lookup table migration
echo ====================================================

sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
set heading off;
set pagesize 0;
set linesize 200;
set term off;
set feedback off;
set show off;
set trimspool on;
spool $TMP_LKPS_OUTPUT_FILE;

    select distinct lki_lkp_id || '.xml' from tlkp_lki_lookup_info;

spool off;
EOF

grep -v 'SQL>' $TMP_LKPS_OUTPUT_FILE > $LKPS_OUTPUT_FILE
rm $TMP_LKPS_OUTPUT_FILE

A=`cat $LKPS_OUTPUT_FILE`
#echo $A

# iterate through the lookup tables (i).
# within those, iterate through the columns (j)
# and create a spec xml for each table with the proper number of columns

for i in $A
do
    #echo 'i: ' $i

    lkp_id=`echo $i | cut -f 1 -d '.'`

    #echo 'lkp_id: ' ${lkp_id}

    sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
    set heading off;
    set pagesize 0;
    set linesize 200;
    set term off;
    set feedback off;
    set show off;
    set trimspool on;

    spool first$i;

        select distinct '<?xml version="1.0" encoding="UTF-8"?>
<TrigoXML>
    <Header>
        <Type>Spec</Type>
        <Action>Create</Action>
        <CompanyName>' || cmp_company_name || '</CompanyName>
        <SpecName>' || lki_name || ' spec</SpecName>
        <Attribs>
            <Attrib>
                <Name>TYPE</Name>
                <Value>LKP_SPEC</Value>
            </Attrib>
            <Attrib>
                <Name>PRIMARY_KEY</Name>
                <Value>' || lki_name || ' spec/Key</Value>
            </Attrib>
        </Attribs>
    </Header>
    <Nodes>
        <Node>
            <Name>Key</Name>
            <Type>ATTRIBUTE</Type>
            <Attribs>
                <Attrib>
                    <Name>MIN_OCCURRENCE</Name>
                    <Value>1</Value>
                </Attrib>
                <Attrib>
                    <Name>MAX_OCCURRENCE</Name>
                    <Value>1</Value>
                </Attrib>
                <Attrib>
                    <Name>TYPE</Name>
                    <Value>STRING</Value>
                </Attrib>
                <Attrib>
                    <Name>DEFAULT_VALUE</Name>
                    <Value></Value>
                </Attrib>
                <Attrib>
                    <Name>LENGTH</Name>
                    <Value>20</Value>
                </Attrib>
            </Attribs>
        </Node>' from tlkp_lki_lookup_info, tsec_cmp_company where lki_lkp_id = $lkp_id and cmp_company_id = lki_cmp_id;

    spool off;

    spool second$i;

        select distinct '        <Node>
            <Name>Value_%PLACE_HOLDER%</Name>
            <Type>ATTRIBUTE</Type>
            <Attribs>
                <Attrib>
                    <Name>MIN_OCCURRENCE</Name>
                    <Value>0</Value>
                </Attrib>
                <Attrib>
                    <Name> MAX_OCCURRENCE</Name>
                    <Value>1</Value>
                </Attrib>
                <Attrib>
                    <Name>TYPE</Name>
                    <Value>STRING</Value>
                </Attrib>
                <Attrib>
                    <Name>DEFAULT_VALUE</Name>
                    <Value></Value>
                </Attrib>
                <Attrib>
                    <Name>LENGTH</Name>
                    <Value>150</Value>
                </Attrib>
            </Attribs>
        </Node>' from tlkp_lki_lookup_info;

    spool off;

    spool third$i;

        select distinct '    </Nodes>
</TrigoXML>' from tlkp_lki_lookup_info;

    spool off;

EOF

    grep -v 'SQL>' first$i > $TEMP_LOOKUP_DIR/specs/first$i
    grep -v 'SQL>' second$i > $TEMP_LOOKUP_DIR/specs/second$i
    grep -v 'SQL>' third$i > $TEMP_LOOKUP_DIR/specs/third$i

    grep -E -v '^[0-9][0-9][0-9]|^ [0-9][0-9]|^  [0-9]' $TEMP_LOOKUP_DIR/specs/first$i > $TEMP_LOOKUP_DIR/first$i
    grep -E -v '^[0-9][0-9][0-9]|^ [0-9][0-9]|^  [0-9]' $TEMP_LOOKUP_DIR/specs/second$i > $TEMP_LOOKUP_DIR/second$i
    grep -E -v '^[0-9][0-9][0-9]|^ [0-9][0-9]|^  [0-9]' $TEMP_LOOKUP_DIR/specs/third$i > $TEMP_LOOKUP_DIR/third$i



    sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
    set heading off;
    set pagesize 0;
    set linesize 200;
    set term off;
    set feedback off;
    set show off;
    set trimspool on;
    spool $TMP_COLS_OUTPUT_FILE;

        select distinct lkv_order from tlkp_lkv_lookup_values where lkv_lkp_id = $lkp_id order by lkv_order asc;

    spool off;
EOF

    grep -v 'SQL>' $TMP_COLS_OUTPUT_FILE > $COLS_OUTPUT_FILE
    rm $TMP_COLS_OUTPUT_FILE

    columns=`cat $COLS_OUTPUT_FILE`
    #echo 'columns: ' $columns


    cat $TEMP_LOOKUP_DIR/first$i \
        > $TEMP_LOOKUP_DIR/specs/$i


    for j in $columns

    do

        #echo 'j: ' $j

        cat $TEMP_LOOKUP_DIR/second$i \
            | sed "s/%PLACE_HOLDER%/"$j"/g" \
            >> $TEMP_LOOKUP_DIR/specs/$i

    done

    cat $TEMP_LOOKUP_DIR/third$i \
        >> $TEMP_LOOKUP_DIR/specs/$i


    rm $TEMP_LOOKUP_DIR/first$i
    rm $TEMP_LOOKUP_DIR/second$i
    rm $TEMP_LOOKUP_DIR/third$i

    rm $TEMP_LOOKUP_DIR/specs/first$i
    rm $TEMP_LOOKUP_DIR/specs/second$i
    rm $TEMP_LOOKUP_DIR/specs/third$i

done

cd $TEMP_LOOKUP_DIR/specs
$JAVA_RT com.ibm.ccd.common.impexp2.DatabaseUploader -action=i -debug=n `ls *.xml`

#echo $A

# iterate through the lookup tables (i),
# create csv import files,
# and execute script for each one

for i in $A
do

    echo "" > $FINAL_CSV_OUTPUT_FILE

    lkp_id=`echo $i | cut -f 1 -d '.'`

    sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
    set heading off;
    set pagesize 0;
    set linesize 200;
    set term off;
    set feedback off;
    set show off;
    set trimspool on;
    spool $TMP_CSV_OUTPUT_FILE;

        select distinct lki_name from tlkp_lki_lookup_info where lki_lkp_id = $lkp_id;

    spool off;
EOF

    grep -v 'SQL>' $TMP_CSV_OUTPUT_FILE > $CSV_OUTPUT_FILE
    lkp_name=`cat $CSV_OUTPUT_FILE`

    echo ====================================================
    echo creating import files for lookup table
    echo ====================================================

    sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
    set heading off;
    set pagesize 0;
    set linesize 200;
    set term off;
    set feedback off;
    set show off;
    set trimspool on;
    spool $TMP_CSV_OUTPUT_FILE;

        select distinct lkv_key from tlkp_lkv_lookup_values where lkv_lkp_id = $lkp_id;

    spool off;
EOF

    grep -v 'SQL>' $TMP_CSV_OUTPUT_FILE > $CSV_OUTPUT_FILE

    B=`cat $CSV_OUTPUT_FILE`
    #echo $B

    for j in $B

    do

        key=`echo $j`

        #echo 'key: ' ${key}

        echo "" >> $FINAL_CSV_OUTPUT_FILE
        echo $key >> $FINAL_CSV_OUTPUT_FILE


        sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
        set heading off;
        set pagesize 0;
        set linesize 200;
        set term off;
        set feedback off;
        set show off;
        set trimspool on;
        spool $TMP_COLS_OUTPUT_FILE;

            select distinct lkv_order from tlkp_lkv_lookup_values where lkv_lkp_id = $lkp_id order by lkv_order asc;

        spool off;
EOF

        grep -v 'SQL>' $TMP_COLS_OUTPUT_FILE > $COLS_OUTPUT_FILE

        rm $TMP_COLS_OUTPUT_FILE

        columns=`cat $COLS_OUTPUT_FILE`

        #echo 'columns: ' $columns

        for k in $columns

        do

            echo "" > $TMP_CSV_OUTPUT_FILE

            column=`echo $k`

            #echo 'column: ' ${column}

            sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
            set heading off;
            set pagesize 0;
            set linesize 200;
            set term off;
            set feedback off;
            set show off;
            set trimspool on;
            spool $TMP_CSV_OUTPUT_FILE;

                select ',' || lkv_value from tlkp_lkv_lookup_values where lkv_lkp_id = $lkp_id and lkv_key = '$key' and lkv_order = $column;

            spool off;
EOF

            grep -v 'SQL>' $TMP_CSV_OUTPUT_FILE >> $FINAL_CSV_OUTPUT_FILE

            rm $TMP_CSV_OUTPUT_FILE

        done

    done

    awk '{  RS="\n\n"
        str=$0
        gsub(/\n/,"",str)
        print(str)
        }' $FINAL_CSV_OUTPUT_FILE > tmp.out

    #echo "grepping..."
    grep -v '^$' tmp.out > $FINAL_CSV_OUTPUT_FILE
    #echo "done grepping..."

    rm tmp.out

    mv $FINAL_CSV_OUTPUT_FILE $TEMP_LOOKUP_DIR/csv/lookup_table.csv

    sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
    set heading off;
    set pagesize 0;
    set linesize 200;
    set term off;
    set feedback off;
    set show off;
    set trimspool on;
    spool $TEMP_LOOKUP_DIR/lookup.xml;

        select distinct '<?xml version="1.0" encoding="UTF-8"?>
<DocListXML>
    <Doc type="lkp">
        <LocalPath>/schema/create/_lookup_table_migration/csv/lookup_table.csv</LocalPath>
        <StorePath>/archives/lkp/' || lki_name || '.lkp</StorePath>
        <Attribs>
            <Attrib name="name" value="' || lki_name || '"/>
            <Attrib name="type" value="LOOKUP_SINGLE_STRING"/>
            <Attrib name="spec" value="' || lki_name || ' spec"/>
            <Attrib name="script_path" value="/scripts/import/lkp/CSV Lookup Table Import"/>
        </Attribs>
    </Doc>
</DocListXML>' from tlkp_lki_lookup_info where lki_lkp_id = $lkp_id;

    spool off;
EOF

    grep -v 'SQL>' $TEMP_LOOKUP_DIR/lookup.xml > $TEMP_LOOKUP_DIR/_lookup.xml

    grep -E -v '^[0-9][0-9][0-9]|^ [0-9][0-9]|^  [0-9]' $TEMP_LOOKUP_DIR/_lookup.xml > $TEMP_LOOKUP_DIR/lookup.xml

    rm $TEMP_LOOKUP_DIR/_lookup.xml

    sqlplus ${CONNECTION} <<EOF > /dev/null 2>&1
    set heading off;
    set pagesize 0;
    set linesize 200;
    set term off;
    set feedback off;
    set show off;
    set trimspool on;
    spool $TEMP_LOOKUP_DIR/_company_code.out;

        select distinct cmp_company_code from tsec_cmp_company, tlkp_lki_lookup_info where cmp_company_id = lki_cmp_id and lki_lkp_id = $lkp_id;

    spool off;
EOF

    grep -v 'SQL>' $TEMP_LOOKUP_DIR/_company_code.out > $TEMP_LOOKUP_DIR/company_code.out

    rm $TEMP_LOOKUP_DIR/_company_code.out

    CMP_CODE=`cat $TEMP_LOOKUP_DIR/company_code.out`
    #echo "CMP_CODE: " $CMP_CODE

    echo ====================================================
    echo loading import scripts for migration
    echo ====================================================
    $JAVA_RT com.ibm.ccd.common.docstore.util.DocLoader $CMP_CODE  ${DB_ROOT_DIR}/schema/create/lkp_migration_import_script.xml Cp1252

    echo ====================================================
    echo loading lookup table for migration
    echo ====================================================
    $JAVA_RT com.ibm.ccd.common.docstore.util.DocLoader $CMP_CODE ${TEMP_LOOKUP_DIR}/lookup.xml Cp1252

done

rm $LKPS_OUTPUT_FILE
rm $COLS_OUTPUT_FILE

rm -fr $TEMP_LOOKUP_DIR
