#!/bin/bash
# IBM Confidential
# OCO Source Materials
# 5724-V51
#
# (c) Copyright IBM Corp. 2000, 2008 All Rights Reserved.
#
# The source code for this program is not published or otherwise
# divested of its trade secrets, irrespective of what has been
# deposited with the U.S. Copyright Office.
. ${TOP}/bin/get_params.sh

. ${TOP}/src/db/schema/util/set_db.sh

${ECHO}
${ECHO} ====================================================
${ECHO} Deleting old info for trigo
${ECHO} ====================================================
${ECHO}

. ${DB_DIR}/util/cleanup_cmp.sh --code=trigo --confirm_db=no

${ECHO}
${ECHO} ============================================================
${ECHO} Creating company and populating related info in db for trigo
${ECHO} ============================================================
${ECHO}

#${TRIGO_SQLPLUS} ${CONNECTION} <<EOF
#${DB_SQLFILE_EXECUTE} $DB_SCRIPTS/create_ccd_comp.sql
#EOF

. ${DB_DIR}/util/run_db_cmd.sh --file=$DB_SCRIPTS/create_ccd_comp.sql


# Krishna - password for trigo_root need not be set when 
# recreating companies other than trigo or creating any 
# company. If it's a fresh creation of trigo then we are 
# complying with the original behaviour where by the code 
# below was commented out.

if [[ "$CMP_NAME" = "trigo" && "$_CCD_ACTION" = "recreate" ]]
then

   $JAVA_RT com.ibm.ccd.common.security.UpdatePassword -cmp_code=trigo -username=trigo_root -password=trigo_root_pw

fi


${ECHO}
${ECHO} ====================================================================
${ECHO} Create basic role for Trigo users
${ECHO} ====================================================================
${ECHO}


. ${TOP}/src/db/schema/trigo/set_create_ccd.sh --confirm_db=no

CMP_DIR=$DB_DIR/cmp

BASIC_SCRIPT_SRC_FILE=${CMP_DIR}/basic_company_setup.script
BASIC_SCRIPT_FILE=${CMP_DIR}/basic_company_setup.script.tmp

${ECHO} ====================================================
${ECHO} Creating sql script for trigo
${ECHO} ====================================================

${CAT} ${BASIC_SCRIPT_SRC_FILE} \
    | ${SED} "s/%CMP_CODE%/trigo/g" \
    | ${SED} "s/%CMP_NAME%/Trigo/g" \
    > ${BASIC_SCRIPT_FILE}

# Krishna - The following piece of code is not needed when
# the company code is trigo and action is recreation of the
# trigo company since all these specs already exist from the
# previous creation of the trigo company

if [[ "$CMP_NAME" != "trigo" && "$_CCD_ACTION" != "recreate" ]]
then

   ${ECHO}
   ${ECHO} ====================================================
   ${ECHO} Loading specs
   ${ECHO} ====================================================
   ${ECHO}

   cd ${TOP}/src/db/specs/all
   $JAVA_RT com.ibm.ccd.content.impexp.DatabaseUploader -action=i -debug=n `ls *.xml`

fi

${ECHO}
${ECHO} ====================================================
${ECHO} Building basic objects, users, roles for trigo
${ECHO} ====================================================
${ECHO}
${JAVA_RT} com.ibm.ccd.common.interpreter.test.TestScript --companycode="$CMP_CODE" \
                                              --username="trigo_root" \
                                              --scriptpath="${BASIC_SCRIPT_FILE}"


${RM} ${BASIC_SCRIPT_FILE}

${ECHO}
${ECHO} ====================================================
${ECHO} COMMON_INFO_LOAD_SCRIPT_SH 
${ECHO} ====================================================
${ECHO}

${JAVA_RT_NOOUT} com.ibm.ccd.docstore.util.DocLoader trigo Admin ${SCRIPTS_DIR}/common/ldap_scripts.xml Cp1252

${ECHO}
${ECHO} ====================================================
${ECHO} Create PIM scripts new in 6.0.0
${ECHO} ====================================================
${ECHO}

${JAVA_RT_NOOUT} com.ibm.ccd.docstore.util.DocLoader trigo Admin ${SCRIPTS_DIR}/common/report_scripts.xml Cp1252

